@@ -145,12 +145,14 @@ def read_package_metadata(extracted_package_directory):
         return None
     else:
         with open(path, 'r') as f:
-            package_metadata = PackageMetadata(**json.loads(f.read()))
-            if package_metadata.package_metadata_version != 1:
+            data = json.loads(f.read())
+            if data.get('package_metadata_version') != 1:
                 raise CondaUpgradeError(dals("""
                 The current version of conda is too old to install this package. (This version
                 only supports link.json schema version 1.)  Please update conda to install
-                this package."""))
+                this package.
+                """))
+        package_metadata = PackageMetadata(**data)
         return package_metadata
 
 
