@@ -1,16 +1,20 @@
 from __future__ import absolute_import, print_function
 
-import os
 from collections import OrderedDict
-from conda.base.context import context
-from conda.cli import common  # TODO: this should never have to import form conda.cli
-from conda.core.linked_data import linked
 from copy import copy
 from itertools import chain
+import os
 
+from conda.base.context import context
+from conda.cli import common  # TODO: this should never have to import form conda.cli
+from conda.common.serialize import yaml_load_standard
+from conda.core.prefix_data import linked
+from conda.models.match_spec import MatchSpec
+from conda_env.yaml import dump
 from . import compat, exceptions, yaml
 from .pip_util import add_pip_installed
 
+
 def load_from_directory(directory):
     """Load and return an ``Environment`` from a given ``directory``"""
     files = ['environment.yml', 'environment.yaml']
@@ -65,7 +69,7 @@ def from_environment(name, prefix, no_builds=False, ignore_channels=False):
 
 def from_yaml(yamlstr, **kwargs):
     """Load and return a ``Environment`` from a given ``yaml string``"""
-    data = yaml.load(yamlstr)
+    data = yaml_load_standard(yamlstr)
     if kwargs is not None:
         for key, value in kwargs.items():
             data[key] = value
@@ -99,6 +103,12 @@ class Dependencies(OrderedDict):
             else:
                 self['conda'].append(common.arg2spec(line))
 
+        if 'pip' in self:
+            if not self['pip']:
+                del self['pip']
+            if not any(MatchSpec(s).name == 'pip' for s in self['conda']):
+                self['conda'].append('pip')
+
     # TODO only append when it's not already present
     def add(self, package_name):
         self.raw.append(package_name)
@@ -160,7 +170,7 @@ class Environment(object):
 
     def to_yaml(self, stream=None):
         d = self.to_dict()
-        out = compat.u(yaml.dump(d, default_flow_style=False))
+        out = compat.u(dump(d))
         if stream is None:
             return out
         stream.write(compat.b(out, encoding="utf-8"))
